@@ -6,17 +6,48 @@
 #### for format ad: gerr accounts for incorrect genotype calling with our approach (function of the depth) and gerr
 #### for ad we could add a term in our formula to account for the probability to observe a read incompatible with the genotype
 
-pemission <- function(zooin, id , gerr = 0.001, seqerr = 0.001, zformat = "gt"){
+pemission <- function(zooin, id , gerr = 0.001, seqerr = 0.001, FH = 0.000, zformat = "gt", ibd, ibdpair, haploid){
 
   pemission=matrix(1, zooin@nsnps, 2)
   f1 <- zooin@freqs
   f2 <- 1 - zooin@freqs
 
+  if(ibd){
+    if(zformat == "vcf" | zformat == "haps"){ #### gt = hap1 + hap2 of allele 1, 0 for 22, 1 for 12 and 2 for 11
+
+    if(!haploid){
+      if(ibdpair[2]==1){i1=2*ibdpair[1]-1}
+      if(ibdpair[2]==2){i1=2*ibdpair[1]}
+      if(ibdpair[4]==1){i2=2*ibdpair[3]-1}
+      if(ibdpair[4]==2){i2=2*ibdpair[3]}
+    }else{
+      i1=ibdpair[1]
+      i2=ibdpair[2]
+    }
+
+      geno1 = zooin@genos[,i1]+zooin@genos[,i2]
+      geno1[is.na(geno1)]=9
+
+      pemission[geno1==0, 1]=(1-FH)*(f2[geno1==0]**2)+FH*(f2[geno1==0])
+      pemission[geno1==1, 1]=(1-FH)*(2*f1[geno1==1]*f2[geno1==1])
+      pemission[geno1==2, 1]=(1-FH)*(f1[geno1==2]**2)+FH*(f1[geno1==2])
+
+      pemission[geno1==0, 2]=f2[geno1==0]*(1-gerr)
+      pemission[geno1==1, 2]=gerr
+      pemission[geno1==2, 2]=f1[geno1==2]*(1-gerr)
+
+      rm(geno1)
+
+      return(pemission)
+    }
+
+  }else{
+
   if(zformat == "gt"){ #### gt = number of allele 1, 0 for 22, 1 for 12 and 2 for 11
 
-    pemission[zooin@genos[,id]==0, 1]=f2[zooin@genos[,id]==0]**2
-    pemission[zooin@genos[,id]==1, 1]=2*f1[zooin@genos[,id]==1]*f2[zooin@genos[,id]==1]
-    pemission[zooin@genos[,id]==2, 1]=f1[zooin@genos[,id]==2]**2
+    pemission[zooin@genos[,id]==0, 1]=(1-FH)*(f2[zooin@genos[,id]==0]**2)+FH*(f2[zooin@genos[,id]==0])
+    pemission[zooin@genos[,id]==1, 1]=(1-FH)*(2*f1[zooin@genos[,id]==1]*f2[zooin@genos[,id]==1])
+    pemission[zooin@genos[,id]==2, 1]=(1-FH)*(f1[zooin@genos[,id]==2]**2)+FH*(f1[zooin@genos[,id]==2])
 
     pemission[zooin@genos[,id]==0, 2]=f2[zooin@genos[,id]==0]*(1-gerr)
     pemission[zooin@genos[,id]==1, 2]=gerr
@@ -31,7 +62,7 @@ pemission <- function(zooin, id , gerr = 0.001, seqerr = 0.001, zformat = "gt"){
     pr12=zooin@genos[,(3*id-1)]
     pr22=zooin@genos[,(3*id)]
 
-    pemission[,1]=pr11*f1**2+pr12*2*f1*f2+pr22*f2**2
+    pemission[,1]=(1-FH)*(pr11*f1**2+pr12*2*f1*f2+pr22*f2**2)+FH*(pr11*f1+pr22*f2)
     pemission[,2]=(pr11*f1+pr22*f2)*(1-gerr)+pr12*gerr
 
     pemission[((pr11+pr12+pr22) == 0),1]=1
@@ -53,7 +84,7 @@ pemission <- function(zooin, id , gerr = 0.001, seqerr = 0.001, zformat = "gt"){
     pr12[prT > 0]=pr12[prT > 0]/prT[prT > 0]
     pr22[prT > 0]=pr22[prT > 0]/prT[prT > 0]
 
-    pemission[,1]=pr11*f1**2+pr12*2*f1*f2+pr22*f2**2
+    pemission[,1]=(1-FH)*(pr11*f1**2+pr12*2*f1*f2+pr22*f2**2)+FH*(pr11*f1+pr22*f2)
     pemission[,2]=(pr11*f1+pr22*f2)*(1-gerr)+pr12*gerr
 
     pemission[(pr0 == 0),1]=1
@@ -73,7 +104,7 @@ pemission <- function(zooin, id , gerr = 0.001, seqerr = 0.001, zformat = "gt"){
     pr12[prT > 0]=pr12[prT > 0]/prT[prT > 0]
     pr22[prT > 0]=pr22[prT > 0]/prT[prT > 0]
 
-    pemission[,1]=pr11*f1**2+pr12*2*f1*f2+pr22*f2**2
+    pemission[,1]=(1-FH)*(pr11*f1**2+pr12*2*f1*f2+pr22*f2**2)+FH*(pr11*f1+pr22*f2)
     pemission[,2]=(pr11*f1+pr22*f2)*(1-gerr)+pr12*gerr
 
     pemission[(zooin@genos[,(2*id-1)]+zooin@genos[,(2*id)]) == 0,1]=1
@@ -82,5 +113,24 @@ pemission <- function(zooin, id , gerr = 0.001, seqerr = 0.001, zformat = "gt"){
     return(pemission)
   }
 
+  if(zformat == "vcf" | zformat == "haps"){ #### gt = hap1 + hap2 of allele 1, 0 for 22, 1 for 12 and 2 for 11
+
+    geno1 = zooin@genos[,(2*id-1)]+zooin@genos[,(2*id)]
+    geno1[is.na(geno1)]=9
+
+    pemission[geno1==0, 1]=(1-FH)*(f2[geno1==0]**2)+FH*(f2[geno1==0])
+    pemission[geno1==1, 1]=(1-FH)*(2*f1[geno1==1]*f2[geno1==1])
+    pemission[geno1==2, 1]=(1-FH)*(f1[geno1==2]**2)+FH*(f1[geno1==2])
+
+    pemission[geno1==0, 2]=f2[geno1==0]*(1-gerr)
+    pemission[geno1==1, 2]=gerr
+    pemission[geno1==2, 2]=f1[geno1==2]*(1-gerr)
+
+    rm(geno1)
+
+    return(pemission)
+  }
+  } ## if not ibd
+
 }
 
